pub enum Expr {
Path(ExprPath),
Lit(ExprLit),
Group(ExprGroup),
Binary(ExprBinary),
Unary(ExprUnary),
Call(ExprCall),
Match(ExprMatch),
Block(Block),
}Expand description
Expression in the bootstrap subset.
Variants
Path(ExprPath)
Lit(ExprLit)
Group(ExprGroup)
Binary(ExprBinary)
Unary(ExprUnary)
Call(ExprCall)
Match(ExprMatch)
Block(Block)
Implementations
Sourceimpl Expr
impl Expr
Sourcepub fn meta(&self) -> Option<&Meta>
pub fn meta(&self) -> Option<&Meta>
Returns metadata when the expression carries explicit Draxl metadata.
Sourcepub fn meta_mut(&mut self) -> Option<&mut Meta>
pub fn meta_mut(&mut self) -> Option<&mut Meta>
Returns mutable metadata when the expression carries explicit Draxl metadata.
Sourcepub fn clear_spans(&mut self)
pub fn clear_spans(&mut self)
Removes span data from the expression in place.